@@ -1,7 +1,7 @@
 /*
- * $Id: getpcaps.c,v 1.1.1.1 1999/04/17 22:16:31 morgan Exp $
+ * $Id: getpcaps.c,v 1.2 1999/11/18 06:04:25 morgan Exp $
  *
- * Copyright (c) 1997 Andrew G. Morgan  <morgan@linux.kernel.org>
+ * Copyright (c) 1997 Andrew G. Morgan  <morgan@kernel.org>
  *
  * This displays the capabilities of a given process.
  */
@@ -20,7 +20,7 @@ static void usage(void)
 "usage: getcaps <pid> [<pid> ...]\n\n"
 "  This program displays the capabilities on the queried process(es).\n"
 "  The capabilities are displayed in the cap_from_text(3) format.\n\n"
-"[Copyright (c) 1997-8 Andrew G. Morgan  <morgan@linux.kernel.org>]\n"
+"[Copyright (c) 1997-8 Andrew G. Morgan  <morgan@kernel.org>]\n"
 	);
     exit(1);
 }
@@ -53,29 +53,10 @@ int main(int argc, char **argv)
 	} else {
 	    char *result = cap_to_text(cap_d, &length);
 	    fprintf(stderr, "Capabilities for `%s': %s\n", *argv, result);
-	    free(result);
+	    cap_free(result);
 	    result = NULL;
 	}
     }
 
     return 0;
 }
-
-/*
- * $Log: getpcaps.c,v $
- * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
- * release 1.0 of libcap
- *
- * Revision 1.4  1998/09/20 23:07:08  morgan
- * fixed comment at top
- *
- * Revision 1.3  1998/06/08 00:16:58  morgan
- * change to accommodate alpha (glibc?)
- *
- * Revision 1.2  1998/06/07 01:49:39  morgan
- * added copyright info and some usage info.  Small tidy up.
- *
- * Revision 1.1  1998/04/30 02:53:00  morgan
- * Initial revision
- *
- */
